<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/plan?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// C
	'confirmer_deplacement' => 'Sei sicuro di voler spostare questi elementi?',

	// D
	'deplacement_en_echec' => 'Spostamento fallito.',
	'deplacement_identifiant_absent' => 'Nessuno',
	'deplacement_reussi' => 'Spostamento riuscito.',
	'deplacements_en_echec' => '@nb@ spostamenti non riusciti.',
	'deplacements_reussis' => '@nb@ spostamenti riusciti.',

	// E
	'erreur_aucun_identifiant' => 'Nessun identificativo dell’oggetto.',
	'erreur_autorisation_insuffisante' => 'Autorizzazioni insufficienti.',
	'erreur_deplacement' => 'Spostamento non eseguito.',
	'erreur_deplacement_impossible' => 'Spostamento impossibile',
	'erreur_rubriques_parentes_incorrectes' => 'Rubriche padre non corrette',

	// P
	'plan_titre' => 'Mappa del sito all’interno dello spazio privato',

	// S
	'suggerer_deplier' => 'Questo potrebbe essere causato dallo spostamento di un gruppo di oggetti numeroso: in questo caso l’elenco dei suoi "figli" non viene caricato. È necessario aprire il blocco (si caricherà), richiuderlo e quindi riposizionarlo.',

	// T
	'tous_les_statuts' => 'Tutti gli stati',
];
